@@ -1,3 +1,6 @@
+import os
+
+
 def bar_template():  # Template for load bar
     return '%(label)s  %(bar)s  %(info)s'
 
@@ -11,6 +14,16 @@ def get_ext(file='', path=''):
         return file[index:].lower()
 
 
+def get_file(path):
+    if os.name == 'nt':
+        os.chdir(path[:path.rfind('\\')])
+        fn = path[path.rfind('\\') + 1:]
+    else:
+        os.chdir(path[:path.rfind('/')])
+        fn = path[path.rfind('/') + 1:]
+    return fn
+
+
 def file_types():
     return {'midia': {'images': ('.png', '.jpeg', '.gif', '.bmp', '.tiff', '.svg'),
                       'musics': ('.mp3', '.waw', '.ogg', '.wma'),
