@@ -20,7 +20,7 @@ def organize(path, t, m, d, o, s, v):
     \b
     Organize a folder in a simple way, by predefined execution that separates files
     according to their context or in a personalized way searching for a specific type.
-    [!Important] - Do not use ('') to declarate TYPE on -t option set the value like: -t pdf
+    [!Important] - Do not use ('') to declare TYPE on -t option set the value like: -t pdf
     """
     try:
         os.chdir(path)
@@ -88,16 +88,27 @@ def Zip():
     ...
 
 
-@Zip.command()
+@Zip.command(help='See the files on a zip')
 @click.argument('path', metavar='<path>', type=click.Path(exists=True))
-@click.option('-v', is_flag=True, default=False, show_default=True, help='Verbose mode ')
-def compress(path, v):
-    """\b
-    Compress files in zip archive
-    \b
-    This command compress all files in one folder
-    Recommended usage: zip compress ./folder or /User/folder
-    """
+def view(path):
+    fn = get_file(path)
+    if not fn.endswith('.zip'):
+        fn += '.zip'
+    zip = zipfile.ZipFile(fn, 'r')
+    list = zip.namelist()
+    if len(list) <= 0:
+        print('Error, no the zip are empty or can\'t be readied')
+    else:
+        print()
+        for file in list:
+            print(file)
+
+
+@Zip.command(help='Compress a folder in zip archive')
+@click.argument('path', metavar='<path>', type=click.Path(exists=True))
+@click.option('-v', is_flag=True, default=True, show_default=True, help='Verbose mode ')
+@click.option('-fo', is_flag=True, default=False, show_default=True, help='Files only mode')
+def compress(path, v, fo):
     fn = get_ext(path=path) + '.zip'
     os.chdir(path)
     arch = 0
@@ -105,42 +116,64 @@ def compress(path, v):
     print(f'Compacting archives, please wait...')
     print() if v else None
     print('  - - Process list - -') if v else None
-    for folder, sub_folders, files in os.walk('.'):
-        for file in files:
-            if file != fn and file not in zip.namelist():
-                print(f'Compacting: {file}') if v else None
-                zip.write(os.path.join(folder, file),
-                          os.path.relpath(os.path.join(folder, file), '.'),
-                          compress_type=zipfile.ZIP_DEFLATED)
-                arch += 1
+    if fo:
+        way = os.getcwd()
+        for folder, sub_folders, files in os.walk('.'):
+            for file in files:
+                if file != fn:
+                    try:
+                        os.chdir(folder)
+                        print(f'Compacting: {file}') if v else None
+                        zip.write(file, compress_type=zipfile.ZIP_DEFLATED)
+                        arch += 1
+                        os.chdir(way)
+                    except:
+                        pass
+    else:
+        for folder, sub_folders, files in os.walk('.'):
+            for file in files:
+                if file != fn:
+                    print(f'Compacting: {file}') if v else None
+                    zip.write(os.path.join(folder, file),
+                              os.path.relpath(os.path.join(folder, file), '.'),
+                              compress_type=zipfile.ZIP_DEFLATED)
+                    arch += 1
     print() if v else None
     print(f'Process completed, {arch} files compacted')
     zip.close()
     print('Moving zipfile to parent folder...')
-    if fn in os.listdir('..'):
-        try:
-            raise Exception(f'Error "{fn}" already exists in {os.path.dirname(os.getcwd())}')
-        except Exception as e:
-            print(e)
+    if fn == '..zip':  # If the path = '.'
+        dir_name = os.getcwd()[os.getcwd().rfind('\\')+1:] + '.zip'
+        os.rename(fn, dir_name)
+        fn = dir_name
     else:
-        print('Concluded successfully')
-
+        os.chdir('..')
+        try:
+            sh.move(fn, '.')
+        except:
+            print('Error: File not moved, still in root')
+    print(f'Concluded successfully -> {os.path.join(os.getcwd(), fn)}')
 
 
 @Zip.command(help='Extract zipfile')
-@click.argument('fn', metavar='<file_name>', type=click.STRING)
-@click.argument('path', metavar='<path>', type=click.Path(exists=True), default=".", required=False)
-@click.option('-v', '-verbose', is_flag=True, default=False, show_default=True, help='Verbose mode ')
-def extract(path, fn, v, ex=0):
-    os.chdir(path)
+@click.argument('path', metavar='<file_path>', type=click.Path(exists=True))
+@click.option('-to', type=click.Path(exists=True), help='Extract to')
+@click.option('-v', is_flag=True, default=False, show_default=True, help='Verbose mode ')
+def extract(path, to, v, ex=0):
+    fn = get_file(path)
     if not fn.endswith('.zip'):
         fn += '.zip'
-    assert zipfile.is_zipfile(fn), f'Assertion error, can\'t find {fn} on {os.getcwd()}'
     zip = zipfile.ZipFile(fn, 'r')
     list = zip.namelist()
     click.secho(f'{len(list)} Files founded in {fn}') if v else None  # Verbose
-    click.secho(f'{list}\n') if v else None  # Verbose
-    assert len(list) >= 0, f'Assertion error, <file> is empty or can\'t be readied>'
+    if len(list) <= 0:
+        print(f'Error, {fn} is empty or can\'t be readied>')
+        return
+    if to:
+        try:
+            os.chdir(to)
+        except Exception as e:
+            print(e)
     with click.progressbar(range(len(zip.namelist())), empty_char='─', fill_char='█', bar_template=bar_template()) as p:
         for f in p:
             click.secho(f' - Extracting {list[f]}') if v else None  # Verbose
@@ -150,4 +183,4 @@ def extract(path, fn, v, ex=0):
             except Exception as e:
                 print(e) if v else None
     zip.close()
-    click.secho(f'{ex} files extracted')
+    click.secho(f' Process completed: {ex} files extracted')
